@@ -320,10 +320,10 @@ class WAS (wsgiappservice.WAS):
         return self.render (template_file, _do_not_use_this_variable_name_ = {}, **karg)
 
     # Map responses ------------------------------------
-    def _mapped_api_callback (self, was, tasks, status, template_file = None):
+    def _mapped_callback (self, was, tasks, status, template_file = None):
         data = tasks.dict ()
         if template_file:
-            return was.render (template_file, data)
+            return was.render_or_API (template_file, data)
         else:
             return was.API (status, data)
 
@@ -332,13 +332,11 @@ class WAS (wsgiappservice.WAS):
             status, tasks = tasks
         except ValueError:
             status, tasks = "200 OK", tasks [0]
-        respfunc = partial (self._mapped_api_callback, status = status)
+        respfunc = partial (self._mapped_callback, status = status)
         return tasks.then (respfunc)
 
     def render_or_Mapped (self, template_file, tasks):
-        if self.request.acceptable ('application/json'):
-            return self.Mapped (tasks)
-        respfunc = partial (self._mapped_api_callback, status = '200 OK', template_file = template_file)
+        respfunc = partial (self._mapped_callback, status = '200 OK', template_file = template_file)
         return tasks.then (respfunc)
 
     def Map (self, *commits, **corequests):
@@ -346,12 +344,11 @@ class WAS (wsgiappservice.WAS):
         if commits and isinstance (commits [0], str):
             status, commits = commits [0], commits [1:]
         tasks = self.Tasks (*commits, **corequests)
-        respfunc = partial (self._mapped_api_callback, status = status)
+        respfunc = partial (self._mapped_callback, status = status)
         return tasks.then (respfunc)
 
     def render_or_Map (self, template_file, *commits, **corequests):
-        if self.request.acceptable ('application/json'):
-            return self.Map (*commits, **corequests)
         tasks = self.Tasks (*commits, **corequests)
-        respfunc = partial (self._mapped_api_callback, status = '200 OK', template_file = template_file)
+        respfunc = partial (self._mapped_callback, status = '200 OK', template_file = template_file)
         return tasks.then (respfunc)
+
